
# Type: description


a human-readable description of a thing

URI: [biolink:description](https://w3id.org/biolink/vocab/description)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>OPT</sub> [NarrativeText](types/NarrativeText.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children

 *  [entity to phenotypic feature association➞description](entity_to_phenotypic_feature_association_description.md)

## Used by

 * [RNAProduct](RNAProduct.md)
 * [RNAProductIsoform](RNAProductIsoform.md)
 * [ActivityAndBehavior](ActivityAndBehavior.md)
 * [AdministrativeEntity](AdministrativeEntity.md)
 * [AnatomicalEntity](AnatomicalEntity.md)
 * [Attribute](Attribute.md)
 * [BiologicalEntity](BiologicalEntity.md)
 * [BiologicalProcess](BiologicalProcess.md)
 * [BiologicalProcessOrActivity](BiologicalProcessOrActivity.md)
 * [BiologicalSex](BiologicalSex.md)
 * [Carbohydrate](Carbohydrate.md)
 * [Case](Case.md)
 * [Cell](Cell.md)
 * [CellLine](CellLine.md)
 * [CellularComponent](CellularComponent.md)
 * [ChemicalExposure](ChemicalExposure.md)
 * [ChemicalSubstance](ChemicalSubstance.md)
 * [ClinicalEntity](ClinicalEntity.md)
 * [ClinicalIntervention](ClinicalIntervention.md)
 * [ClinicalModifier](ClinicalModifier.md)
 * [ClinicalTrial](ClinicalTrial.md)
 * [CodingSequence](CodingSequence.md)
 * [ConfidenceLevel](ConfidenceLevel.md)
 * [DataFile](DataFile.md)
 * [DataSet](DataSet.md)
 * [DataSetSummary](DataSetSummary.md)
 * [DataSetVersion](DataSetVersion.md)
 * [Device](Device.md)
 * [Disease](Disease.md)
 * [DiseaseOrPhenotypicFeature](DiseaseOrPhenotypicFeature.md)
 * [DistributionLevel](DistributionLevel.md)
 * [Drug](Drug.md)
 * [DrugExposure](DrugExposure.md)
 * [EntityToPhenotypicFeatureAssociation](EntityToPhenotypicFeatureAssociation.md)
 * [EnvironmentalFeature](EnvironmentalFeature.md)
 * [EnvironmentalProcess](EnvironmentalProcess.md)
 * [EvidenceType](EvidenceType.md)
 * [Exon](Exon.md)
 * [ExposureEvent](ExposureEvent.md)
 * [FrequencyValue](FrequencyValue.md)
 * [Gene](Gene.md)
 * [GeneFamily](GeneFamily.md)
 * [GeneOntologyClass](GeneOntologyClass.md)
 * [GeneOrGeneProduct](GeneOrGeneProduct.md)
 * [GeneProduct](GeneProduct.md)
 * [GeneProductIsoform](GeneProductIsoform.md)
 * [Genome](Genome.md)
 * [GenomicEntity](GenomicEntity.md)
 * [Genotype](Genotype.md)
 * [GenotypicSex](GenotypicSex.md)
 * [GeographicLocation](GeographicLocation.md)
 * [GeographicLocationAtTime](GeographicLocationAtTime.md)
 * [GrossAnatomicalStructure](GrossAnatomicalStructure.md)
 * [Haplotype](Haplotype.md)
 * [IndividualOrganism](IndividualOrganism.md)
 * [InformationContentEntity](InformationContentEntity.md)
 * [LifeStage](LifeStage.md)
 * [MacromolecularComplex](MacromolecularComplex.md)
 * [MacromolecularMachine](MacromolecularMachine.md)
 * [MaterialSample](MaterialSample.md)
 * [Metabolite](Metabolite.md)
 * [MicroRNA](MicroRNA.md)
 * [MolecularActivity](MolecularActivity.md)
 * [MolecularEntity](MolecularEntity.md)
 * [NamedThing](NamedThing.md)
 * [NoncodingRNAProduct](NoncodingRNAProduct.md)
 * [Occurrent](Occurrent.md)
 * [Onset](Onset.md)
 * [OntologyClass](OntologyClass.md)
 * [OrganismTaxon](OrganismTaxon.md)
 * [OrganismalEntity](OrganismalEntity.md)
 * [Pathway](Pathway.md)
 * [Phenomenon](Phenomenon.md)
 * [PhenotypicFeature](PhenotypicFeature.md)
 * [PhenotypicSex](PhenotypicSex.md)
 * [PhysicalEntity](PhysicalEntity.md)
 * [PhysiologicalProcess](PhysiologicalProcess.md)
 * [PlanetaryEntity](PlanetaryEntity.md)
 * [PopulationOfIndividualOrganisms](PopulationOfIndividualOrganisms.md)
 * [Procedure](Procedure.md)
 * [Protein](Protein.md)
 * [ProteinIsoform](ProteinIsoform.md)
 * [Provider](Provider.md)
 * [Publication](Publication.md)
 * [RelationshipType](RelationshipType.md)
 * [SequenceVariant](SequenceVariant.md)
 * [SeverityValue](SeverityValue.md)
 * [SourceFile](SourceFile.md)
 * [Transcript](Transcript.md)
 * [Treatment](Treatment.md)
 * [Zygosity](Zygosity.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | dcterms:description |
| **In Subsets:** | | translator_minimal |

